@@ -81,14 +81,14 @@ class fillVars(varsShare):
         """Get net domain name"""
         textLines = self._runos("hostname -d 2>&1")
         if textLines is False:
-            cl_overriding.printERROR(_("Error execute 'hostname -d'"))
+            cl_overriding.printERROR(_("Error executing 'hostname -d'"))
             return cl_overriding.exit(1)
         domain = ""
         if textLines:
             domain = textLines[0]
         if not domain:
             cl_overriding.printERROR(_("Error:") + " " +\
-                _("Not found domain name"))
+                _("Domain name not found"))
             cl_overriding.printERROR(\
                 _("Command 'hostname -d' returns an empty value"))
             return cl_overriding.exit(1)
@@ -238,7 +238,8 @@ class fillVars(varsShare):
     def get_hr_cdrom_set(self):
         """Cdrom variable"""
         if os.path.exists('/sys/block/sr0'):
-            textLines = self._runos("udevadm info --query=all --name=/dev/dvdrw")
+            textLines = self._runos(
+                "udevadm info --query=all --name=/dev/dvdrw")
             if not textLines is False:
                 for line in textLines:
                     if "ID_CDROM=1" in line:
