@@ -57,7 +57,7 @@ class patch(_error):
     def processingFile(self, textConfigFile):
         """Обработка конфигурационного файла"""
         if not self.doc:
-            self.setError(_("Can not convert text template in XML"))
+            self.setError(_("Cannot convert the text template in XML"))
             return False
         retTextConfigFile = textConfigFile
         tags = ["reg", "text"]
@@ -66,7 +66,7 @@ class patch(_error):
         for node in  self.rootNode.childNodes:
             if node.nodeType==node.ELEMENT_NODE:
                 if not node.tagName == tags[tagsIndex]:
-                    self.setError(_("Incorrect text template"))
+                    self.setError(_("Incorrect template text"))
                     return False
                 if tagsIndex == 1:
                     tagsIndex = 0
@@ -79,23 +79,23 @@ class patch(_error):
                         if reText is None:
                             textNode = node.toxml().encode("UTF8")
                             self.setError(\
-                            _("Incorrect text template")+ ": \n" +\
+                            _("Incorrect template text")+ ": \n" +\
                               "%s" %textNode)
                             return False
                     else:
                         self.setError(\
-                            _("Incorrect text template '<reg></reg>'"))
+                            _("Incorrect text of template '<reg></reg>'"))
                         return False
                     if not reText.strip():
                         self.setError(\
-                            _("Incorrect text template '<reg>%s</reg>'")\
+                            _("Incorrect text of template '<reg>%s</reg>'")\
                                %reText)
                         return False
                     try:
                         regex = re.compile(reText)
                     except:
                         self.setError(\
-                            _("Incorrect text template '<reg>%s</reg>'")\
+                            _("Incorrect text of template '<reg>%s</reg>'")\
                               %reText)
                         return False
                 elif node.tagName == "text" and regex:
@@ -104,7 +104,7 @@ class patch(_error):
                         if text is None:
                             textNode = node.toxml().encode("UTF8")
                             self.setError(\
-                            _("Incorrect text template")+ ": \n" +\
+                            _("Incorrect template text")+ ": \n" +\
                               "%s" %textNode)
                             return False
                     else:
